@@ -2,6 +2,7 @@ import json
 from contextlib import contextmanager
 from copy import deepcopy
 from pathlib import Path
+from typing import List
 from unittest.mock import patch
 
 from mythx_models.response import (
@@ -127,3 +128,41 @@ def mock_context(
             group_create_patch,
             version_patch,
         )
+
+
+def generate_mythx_config(
+    base_path: str = "",
+    build_directory: str = "build",
+    targets: str = "contracts",
+    not_include: List[str] = [],
+    add_refresh_token: bool = False,
+):
+    config_file = "fuzz:"
+    if "deployed_contract_address" not in not_include:
+        config_file += '\n  deployed_contract_address: "0x7277646075fa72737e1F6114654C5d9949a67dF2"'
+    if "number_of_cores" not in not_include:
+        config_file += "\n  number_of_cores: 1"
+    if "campaign_name_prefix" not in not_include:
+        config_file += '\n  campaign_name_prefix: "ide_test"'
+    if "rpc_url" not in not_include:
+        config_file += f'\n  rpc_url: "http://localhost:9898"'
+    if "faas_url" not in not_include:
+        config_file += f'\n  faas_url: "http://localhost:9899"'
+    if "api_key" not in not_include:
+        config_file += f'\n  api_key:\n    "test"'
+    if "build_directory" not in not_include:
+        config_file += f"\n  build_directory: {base_path}/{build_directory}"
+    if "targets" not in not_include:
+        config_file += f'\n  targets:\n    - "{base_path}/{targets}"'
+
+    if add_refresh_token:
+        config_file += (
+            f'\n  refresh_token: "dGVzdC1jbGllbnQtMTIzOjpleGFtcGxlLXVzLmNvbQ==::2"'
+        )
+
+    return config_file
+
+
+def write_config(*args, **kwargs):
+    with open(".mythx.yml", "w+") as conf_f:
+        conf_f.write(generate_mythx_config(*args, **kwargs))
